const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    const vars = context.steps;
    let daysAgo = vars.transform.days_ago;
    let amount = vars.loop.attributes.points_amount;

    let today = new Date();
    today.setDate(today.getDate() - daysAgo);
    let expireFromDate = today.toISOString().slice(0, 10)

    let appliedAt = vars.loop.attributes.applied_at;

    Mesa.log.info("applied at: " + appliedAt);
    Mesa.log.info("expire from date: " + expireFromDate);

    if (appliedAt < expireFromDate) {
      Mesa.trigger.setTaskExternalData({
        label: "Applied before " + vars.transform.days_ago + " days ago: " + amount + " points - applied: " + appliedAt
      });  
      return Mesa.output.next(payload);
    } else {
      Mesa.trigger.setTaskExternalData({
        label: "Applied after " + vars.transform.days_ago + " days ago: " + amount + " points - applied: " + appliedAt
      });  
      // end of loop
      return Mesa.output.send('custom_1')
    }
  }
}

// if applied at less than x days
//   - create data record
//   - expirable_amount = expired_amount ? (amount - expired_amount) ? amount;
//   - expired_amount = (balance - expirable_amount) > 0 ? expirable_amount : balance;
//   - send points event with expired amount
//   - update data record with expired_amount