const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    const vars = context.steps;
    let balance = vars.rivo_2.attributes.points_tally;

    let expirableAmount = 0;
    if (vars.data.expired_amount) {
      Mesa.log.info("expired amount: " + vars.data.expired_amount);
      expirableAmount = vars.data.amount - vars.data.expired_amount;
    } else {
      Mesa.log.info("none expired yet");
      expirableAmount = vars.data.amount;
    }

    let amountToExpire = 0;
    if (balance > expirableAmount) {
      amountToExpire = expirableAmount;
    } else {
      amountToExpire = balance;
    }

    payload = {
      "expirable_amount": expirableAmount,
      "amount_to_expire": amountToExpire,
    }

    Mesa.trigger.setTaskExternalData({
      label: "Amount to expire: " + amountToExpire + ", expirable amount: " + expirableAmount,
    });  

    Mesa.output.next(payload);
  }
}
